==> react-web-foundation-0.0.1.tgz: package/es/View/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { bool } from "prop-types";
import createElement from "../createElement";
import invariant from "fbjs/lib/invariant";
import StyleSheet from "../StyleSheet";
import React, { Component } from "react";

var View = (_temp = _class = function (_Component) {
  _inherits(View, _Component);

  function View() {
    _classCallCheck(this, View);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  View.prototype.render = function render() {
    // if (process.env.NODE_ENV !== "production") {
    //   React.Children.toArray(this.props.children).forEach(item => {
    //     invariant(
    //       typeof item !== "string",
    //       `Unexpected text node: ${item}. A text node cannot be a child of a <View>.`
    //     );
    //   });
    // }

    var isInAParentText = this.context.isInAParentText;


    var style = StyleSheet.compose(styles.initial, StyleSheet.compose(isInAParentText && styles.inline, this.props.style));

    return createElement("div", _extends({}, this.props, { style: style }));
  };

  return View;
}(Component), _class.displayName = "View", _class.contextTypes = {
  isInAParentText: bool
}, _temp);


var styles = StyleSheet.create({
  // https://github.com/facebook/css-layout#default-values
  initial: {
    alignItems: "stretch",
    borderWidth: 0,
    borderStyle: "solid",
    boxSizing: "border-box",
    display: "flex",
    flexDirection: "column",
    margin: 0,
    padding: 0,
    position: "relative",
    zIndex: 0,
    // fix flexbox bugs
    minHeight: 0,
    minWidth: 0
  },
  inline: {
    display: "inline-flex"
  }
});

export default View;

==> react-web-foundation-0.1.1.tgz: package/es/View/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import { bool } from "prop-types";
import createElement, { ElementPropTypes } from "../createElement";
import invariant from "fbjs/lib/invariant";
import StyleSheet from "../StyleSheet";
import React, { Component } from "react";

var View = (_temp = _class = function (_Component) {
  _inherits(View, _Component);

  function View() {
    _classCallCheck(this, View);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  View.prototype.render = function render() {
    if (process.env.NODE_ENV !== "production") {
      React.Children.toArray(this.props.children).forEach(function (item) {
        invariant(typeof item !== "string", "Unexpected text node: \"" + item + "\". A text node cannot be a child of a <View>. Perhaps you meant to use <Text>.");
      });
    }

    var isInAParentText = this.context.isInAParentText;


    var style = StyleSheet.compose(styles.initial, StyleSheet.compose(isInAParentText && styles.inline, this.props.style));

    return createElement("div", _extends({}, this.props, { style: style }));
  };

  return View;
}(Component), _class.displayName = "View", _class.contextTypes = {
  isInAParentText: bool
}, _temp);
View.propTypes = process.env.NODE_ENV !== "production" ? ElementPropTypes : {};


var styles = StyleSheet.create({
  // https://github.com/facebook/css-layout#default-values
  initial: {
    alignItems: "stretch",
    borderWidth: 0,
    borderStyle: "solid",
    boxSizing: "border-box",
    display: "flex",
    flexDirection: "column",
    margin: 0,
    padding: 0,
    position: "relative",
    zIndex: 0,
    // fix flexbox bugs
    minHeight: 0,
    minWidth: 0
  },
  inline: {
    display: "inline-flex"
  }
});

export default View;
